@@ -29,6 +29,7 @@ import os
 import re
 import shutil
 from abc import ABC, abstractmethod
+from io import StringIO
 from pathlib import Path
 from textwrap import dedent, indent
 from typing import Dict, List, Type
@@ -627,11 +628,15 @@ class ScaffoldABCISkill:
         DialoguesTestFileGenerator,
     ]
 
-    def __init__(self, ctx: Context, skill_name: str, dfa: DFA) -> None:
+    def __init__(self, ctx: Context, skill_name: str, spec_path: Path) -> None:
         """Initialize the utility class."""
         self.ctx = ctx
         self.skill_name = skill_name
-        self.dfa = dfa
+
+        self.spec_path = spec_path
+
+        # process FSM specification
+        self.dfa = DFA.load(StringIO(spec_path.read_text()), input_format="yaml")
 
     @property
     def skill_dir(self) -> Path:
@@ -661,6 +666,7 @@ class ScaffoldABCISkill:
 
         self._remove_pycache()
         self._update_init_py()
+        self._copy_spec_file()
         self._update_config()
 
     def _update_config(self) -> None:
@@ -668,6 +674,11 @@ class ScaffoldABCISkill:
         click.echo("Updating skill configuration...")
         SkillConfigUpdater(self.ctx, self.skill_dir, self.dfa).update()
 
+    def _copy_spec_file(self) -> None:
+        """Copy the spec file in the skill directory."""
+        click.echo("Copying the spec file in the skill directory...")
+        shutil.copy(self.spec_path, self.skill_dir / self.spec_path.name)
+
     def _update_init_py(self) -> None:
         """Update Copyright __init__.py files"""
 
@@ -697,9 +708,4 @@ def fsm(ctx: Context, registry: str, skill_name: str, spec: str) -> None:
     # scaffold AEA skill - as usual
     scaffold_item(ctx, SKILL, skill_name)
 
-    # process FSM specification
-    spec_path = Path(spec)
-    with spec_path.open(encoding="utf-8") as fp:
-        dfa = DFA.load(fp, input_format="yaml")
-
-    ScaffoldABCISkill(ctx, skill_name, dfa).do_scaffolding()
+    ScaffoldABCISkill(ctx, skill_name, Path(spec)).do_scaffolding()
