@@ -116,7 +116,7 @@ kind: PersistentVolumeClaim
 metadata:
   name: logs-pvc
 spec:
-  storageClassName: nfs-client
+  storageClassName: nfs-ephemeral
   accessModes:
     - ReadWriteOnce
   resources:
@@ -128,7 +128,7 @@ kind: PersistentVolumeClaim
 metadata:
   name: tendermint-pvc
 spec:
-  storageClassName: nfs-client
+  storageClassName: nfs-ephemeral
   accessModes:
     - ReadWriteOnce
   resources:
@@ -140,7 +140,7 @@ kind: PersistentVolumeClaim
 metadata:
   name: benchmark-pvc
 spec:
-  storageClassName: nfs-client
+  storageClassName: nfs-ephemeral
   accessModes:
     - ReadWriteOnce
   resources:
@@ -152,7 +152,7 @@ kind: PersistentVolumeClaim
 metadata:
   name: nodes
 spec:
-  storageClassName: nfs-client
+  storageClassName: nfs-ephemeral
   accessModes:
     - ReadWriteOnce
   resources:
